searchNodes=[{"doc":"This module contains functions for signing requests to AWS services.","ref":"aws_signature.html","title":"aws_signature","type":"module"},{"doc":"Same as sign_v4/10 with no options.","ref":"aws_signature.html#sign_v4/9","title":"aws_signature.sign_v4/9","type":"function"},{"doc":"Implements the Signature Version 4 (SigV4) algorithm. This function takes AWS client credentials and request details, based on which it computes the signature and returns headers extended with the authorization entries. DateTime is a datetime tuple used as the request date. You most likely want to set it to the value of calendar:universal_time() when making the request. URL must be valid, with all components properly escaped. For example, &quot;https://example.com/path%20to&quot; is valid, whereas &quot;https://example.com/path to&quot; is not. It is essential that the provided request details are final and the returned headers are used to make the request. All custom headers need to be assembled before the signature is calculated. The signature is computed by normalizing request details into a well defined format and combining it with the credentials using a number of cryptographic functions. Upon receiving a request, the server calculates the signature using the same algorithm and compares it with the value received in headers. For more details check out the AWS documentation . The following options are supported: uri_encode_path When true , the request URI path is URI-encoded during request canonicalization, which is required for every service except S3 . Note that the given URL should already be properly encoded, so this results in each segment being URI-encoded twice, as expected by AWS. Defaults to true .","ref":"aws_signature.html#sign_v4/10","title":"aws_signature.sign_v4/10","type":"function"},{"doc":"Same as sign_v4_query_params/7 with no options.","ref":"aws_signature.html#sign_v4_query_params/7","title":"aws_signature.sign_v4_query_params/7","type":"function"},{"doc":"Implements the Signature Version 4 (SigV4) algorithm for query parameters. This function takes AWS client credentials and request details, based on which it computes the signature and returns the URL extended with the signature entries. Note that anchors are ignored in the resulting URL. DateTime is a datetime tuple used as the request date. You most likely want to set it to the value of calendar:universal_time() when making the request. URL must be valid, with all components properly escaped. For example, &quot;https://example.com/path%20to&quot; is valid, whereas &quot;https://example.com/path to&quot; is not. It is essential that the provided request details are final and the returned query params are used to make the request with the provided URL. The signature is computed by normalizing request details into a well defined format and combining it with the credentials using a number of cryptographic functions. Upon receiving a request, the server calculates the signature using the same algorithm and compares it with the value received in headers. For more details check out the AWS documentation . The following options are supported: ttl Time-to-live value that tells how long this URL is valid in seconds. Defaults to 86400 , which means one day. uri_encode_path When true , the request URI path is URI-encoded during request canonicalization, which is required for every service except S3 . Note that the given URL should already be properly encoded, so this results in each segment being URI-encoded twice, as expected by AWS. Defaults to true . session_token Optional credential parameter if using credentials sourced from the STS service. body Request body to compute SHA256 digest for. Defaults to an empty binary. Note that body_digest always takes precedence when set. body_digest Optional SHA256 digest of the request body. This option can be used to provide a fixed digest value, such as &quot;UNSIGNED-PAYLOAD&quot;, when sending requests without signing the body, which is expected for S3 .","ref":"aws_signature.html#sign_v4_query_params/8","title":"aws_signature.sign_v4_query_params/8","type":"function"},{"doc":"","ref":"aws_signature.html#t:header/0","title":"aws_signature.header/0","type":"type"},{"doc":"","ref":"aws_signature.html#t:headers/0","title":"aws_signature.headers/0","type":"type"},{"doc":"","ref":"aws_signature.html#t:query_param/0","title":"aws_signature.query_param/0","type":"type"},{"doc":"","ref":"aws_signature.html#t:query_params/0","title":"aws_signature.query_params/0","type":"type"},{"doc":"All notable changes to this project will be documented in this file. The format is based on Keep a Changelog .","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"This release changes the default behaviour of sign_v4_query_params . Instead of setting the body digest to &quot;UNSIGNED-PAYLOAD&quot; it now computes the digest of an empty string. To retain the current behaviour you need to pass an option: -sign_v4_query_params(AccessKeyID, SecretAccessKey, Region, Service, DateTime, Method, URL, []). +sign_v4_query_params(AccessKeyID, SecretAccessKey, Region, Service, DateTime, Method, URL, [{body_digest, &lt;&lt;&quot;UNSIGNED-PAYLOAD&quot;&gt;&gt;}]). Added Support for body signing in presigned requests ( #15 ) Changed Default body digest in sign_v4_query_params signature ( #15 )","ref":"changelog.html#v0-3-0-2022-04-12","title":"Changelog - v0.3.0 (2022-04-12)","type":"extras"},{"doc":"Changed Changed sign_v4_query_params signatures to also accept HTTP method ( #11 )","ref":"changelog.html#v0-2-0-2021-09-27","title":"Changelog - v0.2.0 (2021-09-27)","type":"extras"},{"doc":"Added Support for query string signature ( #7 )","ref":"changelog.html#v0-1-1-2021-08-28","title":"Changelog - v0.1.1 (2021-08-28)","type":"extras"},{"doc":"Initial release","ref":"changelog.html#v0-1-0-2021-08-17","title":"Changelog - v0.1.0 (2021-08-17)","type":"extras"},{"doc":"Apache License Version 2.0, January 2004 http://www.apache.org/licenses/ TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION 1. Definitions. &quot;License&quot; shall mean the terms and conditions for use, reproduction, and distribution as defined by Sections 1 through 9 of this document. &quot;Licensor&quot; shall mean the copyright owner or entity authorized by the copyright owner that is granting the License. &quot;Legal Entity&quot; shall mean the union of the acting entity and all other entities that control, are controlled by, or are under common control with that entity. For the purposes of this definition, &quot;control&quot; means (i) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (ii) ownership of fifty percent (50%) or more of the outstanding shares, or (iii) beneficial ownership of such entity. &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity exercising permissions granted by this License. &quot;Source&quot; form shall mean the preferred form for making modifications, including but not limited to software source code, documentation source, and configuration files. &quot;Object&quot; form shall mean any form resulting from mechanical transformation or translation of a Source form, including but not limited to compiled object code, generated documentation, and conversions to other media types. &quot;Work&quot; shall mean the work of authorship, whether in Source or Object form, made available under the License, as indicated by a copyright notice that is included in or attached to the work (an example is provided in the Appendix below). &quot;Derivative Works&quot; shall mean any work, whether in Source or Object form, that is based on (or derived from) the Work and for which the editorial revisions, annotations, elaborations, or other modifications represent, as a whole, an original work of authorship. For the purposes of this License, Derivative Works shall not include works that remain separable from, or merely link (or bind by name) to the interfaces of, the Work and Derivative Works thereof. &quot;Contribution&quot; shall mean any work of authorship, including the original version of the Work and any modifications or additions to that Work or Derivative Works thereof, that is intentionally submitted to Licensor for inclusion in the Work by the copyright owner or by an individual or Legal Entity authorized to submit on behalf of the copyright owner. For the purposes of this definition, &quot;submitted&quot; means any form of electronic, verbal, or written communication sent to the Licensor or its representatives, including but not limited to communication on electronic mailing lists, source code control systems, and issue tracking systems that are managed by, or on behalf of, the Licensor for the purpose of discussing and improving the Work, but excluding communication that is conspicuously marked or otherwise designated in writing by the copyright owner as &quot;Not a Contribution.&quot; &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity on behalf of whom a Contribution has been received by Licensor and subsequently incorporated within the Work. 2. Grant of Copyright License. Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable copyright license to reproduce, prepare Derivative Works of, publicly display, publicly perform, sublicense, and distribute the Work and such Derivative Works in Source or Object form. 3. Grant of Patent License. Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable (except as stated in this section) patent license to make, have made, use, offer to sell, sell, import, and otherwise transfer the Work, where such license applies only to those patent claims licensable by such Contributor that are necessarily infringed by their Contribution(s) alone or by combination of their Contribution(s) with the Work to which such Contribution(s) was submitted. If You institute patent litigation against any entity (including a cross-claim or counterclaim in a lawsuit) alleging that the Work or a Contribution incorporated within the Work constitutes direct or contributory patent infringement, then any patent licenses granted to You under this License for that Work shall terminate as of the date such litigation is filed. 4. Redistribution. You may reproduce and distribute copies of the Work or Derivative Works thereof in any medium, with or without modifications, and in Source or Object form, provided that You meet the following conditions: (a) You must give any other recipients of the Work or Derivative Works a copy of this License; and (b) You must cause any modified files to carry prominent notices stating that You changed the files; and (c) You must retain, in the Source form of any Derivative Works that You distribute, all copyright, patent, trademark, and attribution notices from the Source form of the Work, excluding those notices that do not pertain to any part of the Derivative Works; and (d) If the Work includes a &quot;NOTICE&quot; text file as part of its distribution, then any Derivative Works that You distribute must include a readable copy of the attribution notices contained within such NOTICE file, excluding those notices that do not pertain to any part of the Derivative Works, in at least one of the following places: within a NOTICE text file distributed as part of the Derivative Works; within the Source form or documentation, if provided along with the Derivative Works; or, within a display generated by the Derivative Works, if and wherever such third-party notices normally appear. The contents of the NOTICE file are for informational purposes only and do not modify the License. You may add Your own attribution notices within Derivative Works that You distribute, alongside or as an addendum to the NOTICE text from the Work, provided that such additional attribution notices cannot be construed as modifying the License. You may add Your own copyright statement to Your modifications and may provide additional or different license terms and conditions for use, reproduction, or distribution of Your modifications, or for any such Derivative Works as a whole, provided Your use, reproduction, and distribution of the Work otherwise complies with the conditions stated in this License. 5. Submission of Contributions. Unless You explicitly state otherwise, any Contribution intentionally submitted for inclusion in the Work by You to the Licensor shall be under the terms and conditions of this License, without any additional terms or conditions. Notwithstanding the above, nothing herein shall supersede or modify the terms of any separate license agreement you may have executed with Licensor regarding such Contributions. 6. Trademarks. This License does not grant permission to use the trade names, trademarks, service marks, or product names of the Licensor, except as required for reasonable and customary use in describing the origin of the Work and reproducing the content of the NOTICE file. 7. Disclaimer of Warranty. Unless required by applicable law or agreed to in writing, Licensor provides the Work (and each Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied, including, without limitation, any warranties or conditions of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are solely responsible for determining the appropriateness of using or redistributing the Work and assume any risks associated with Your exercise of permissions under this License. 8. Limitation of Liability. In no event and under no legal theory, whether in tort (including negligence), contract, or otherwise, unless required by applicable law (such as deliberate and grossly negligent acts) or agreed to in writing, shall any Contributor be liable to You for damages, including any direct, indirect, special, incidental, or consequential damages of any character arising as a result of this License or out of the use or inability to use the Work (including but not limited to damages for loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses), even if such Contributor has been advised of the possibility of such damages. 9. Accepting Warranty or Additional Liability. While redistributing the Work or Derivative Works thereof, You may choose to offer, and charge a fee for, acceptance of support, warranty, indemnity, or other liability obligations and/or rights consistent with this License. However, in accepting such obligations, You may act only on Your own behalf and on Your sole responsibility, not on behalf of any other Contributor, and only if You agree to indemnify, defend, and hold each Contributor harmless for any liability incurred by, or claims asserted against, such Contributor by reason of your accepting any such warranty or additional liability. END OF TERMS AND CONDITIONS Copyright 2021, Jonatan Kłosko &lt;jonatanklosko@gmail.com&gt;. Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"license.html","title":"LICENSE","type":"extras"}]